@@ -1035,7 +1035,8 @@ class JobSettingConverter(Converter):
             node_selector = None if x.node_selector is None else x.node_selector.get_value(),
             volumes = None if x.volumes is None else [volume_setting_converter.to_do(i) for i in x.volumes],
             selector = None if x.selector is None else [label_selector_converter.to_do(i) for i in x.selector],
-            dns_policy = None if x.dns_policy is None else x.dns_policy.get_value()
+            dns_policy = None if x.dns_policy is None else x.dns_policy.get_value(),
+            service_account_name = None if x.service_account_name is None else x.service_account_name.get_value()
         )
 
 class JobConverter(Converter):
