@@ -2,6 +2,7 @@ import datetime
 from dataclasses import dataclass
 from typing import Dict, List, Optional, Union
 from ddd_objects.infrastructure.do import BaseDO
+from pydantic import BaseModel
 
 @dataclass
 class ConditionDO(BaseDO):
@@ -309,12 +310,18 @@ class VolumeSourceDO(BaseDO):
     items: Optional[List[KeyToPathDO]] = None
     optional: Optional[bool] = None
 
+@dataclass
+class PersistentVolumeClaimeVolumeSourceDO(BaseModel):
+    claim_name: str
+    read_only: Optional[bool] = None
+
 @dataclass
 class VolumeSettingDO(BaseDO):
     volume_name: str
     empty_dir: Optional[bool] = None
     config_map: Optional[VolumeSourceDO] = None
     secret: Optional[VolumeSourceDO] = None
+    persistent_volume_claim: Optional[PersistentVolumeClaimeVolumeSourceDO] = None
 
 @dataclass
 class VolumeMountDO(BaseDO):
@@ -429,3 +436,48 @@ class PodLogSettingDO(BaseDO):
     container_name: Optional[str]=None
     tail_lines: int=500
 
+class StorageClassDO(BaseModel):
+    name: str
+    provisioner: str
+    reclaim_policy: str
+    volume_binding_mode: str
+    namespace_name: str
+
+class NFSVolumeSourceDO(BaseModel):
+    path: str
+    server: str
+    read_only: Optional[bool]=None
+
+class LocalVolumeSourceDO(BaseModel):
+    path: str
+    fs_type: Optional[str]=None
+
+class NodeSelectorRequirementDO(BaseModel):
+    key: str
+    operator: str
+    values: List[str]
+
+class NodeAffinityDO(BaseModel):
+    match_expressions: Optional[List[NodeSelectorRequirementDO]]=None
+    match_fields: Optional[List[NodeSelectorRequirementDO]]=None
+
+class PersistentVolumeDO(BaseModel):
+    name: str
+    namespace: str
+    persistent_volume_claim_name: Optional[str] = None
+    storage_class_name: Optional[str]=None
+    capacity: Optional[Dict]=None
+    access_modes: Optional[List[str]]=None
+    persistent_volume_reclaim_policy: Optional[str]=None
+    nfs: Optional[NFSVolumeSourceDO]=None
+    local: Optional[LocalVolumeSourceDO]=None
+    node_affinity: Optional[List[NodeAffinityDO]]=None
+
+class PersistentVolumeClaimDO(BaseModel):
+    name: str
+    namespace: str
+    labels: Optional[Dict]=None
+    access_modes: Optional[List[str]]=None
+    storage_class_name: Optional[str]=None
+    limits: Optional[Dict]=None
+    requests: Optional[Dict]=None
\ No newline at end of file
